@@ -31,14 +31,14 @@ except:
 try:
     import osso
     OSSO = True
-    osso_c = osso.Context("net.yerga.stockthis", "0.2", False)
+    #osso_c = osso.Context("net.yerga.stockthis", "0.2", False)
 except:
     OSSO = False
 
 from marketdata import markets, idmarket, localmarkets, localids
 
 #TODO: detect if running in Fremantle
-FREMANTLE=False
+FREMANTLE=True
 
 #detect if is ran locally or not
 import sys
